export enum HttpStatusCode {
	/**
	 * Status code for a request indicating that the server received the request headers
	 * and the client should proceed to send the request body.
	 * @enum {number}
	 */
	Continue = 100,

	/**
	 * Status code for a request indicating that the requester has asked the server to switch protocols.
	 * @enum {number}
	 */
	SwitchingProtocols = 101,

	/**
	 * Status code for a request indicating that the server has received and is processing the request,
	 * but no response is available yet.
	 * @enum {number}
	 */
	Processing = 102,

	/**
	 * Successful HTTP response
	 * @enum {number}
	 */
	Ok = 200,
	/**
	 * Request has been fulfilled; new resource created as a result.
	 * @enum {number}
	 */
	Created = 201,
	/**
	 * Request accepted, but not yet processed.
	 * @enum {number}
	 */
	Accepted = 202,
	/**
	 * Request successful. Meta-information returned is from original server, not local.
	 * @enum {number}
	 */
	NonAuthoritativeInformation = 203,
	/**
	 * Request processed. No content returned.
	 * @enum {number}
	 */
	NoContent = 204,
	/**
	 * Server specifies part of document should be reset.
	 * @enum {number}
	 */
	ResetContent = 205,
	/**
	 * Partial content returned due to GET.
	 * @enum {number}
	 */
	PartialContent = 206,
	/**
	 * Multiple Resource Meta-Data: Could be used for collection instances.
	 * @enum {number}
	 */
	MultiStatus = 207,
	/**
	 * Status code used to indicate that a certain request has been already reported.
	 * @enum {number}
	 */
	AlreadyReported = 208,
	/**
	 * The server has fulfilled the request for the content, and the content is being conveyed in a manner described by the Content-Encoding, Content-Range, and Content-Type headers.
	 * @enum {number}
	 */
	ImUsed = 226,

	/**
	 * @enum {number}
	 * @description HTTP status code for multiple choices
	 */
	MultipleChoices = 300,

	/**
	 * @enum {number}
	 * @description HTTP status code for moved permanently
	 */
	MovedPermanently = 301,

	/**
	 * @enum {number}
	 * @description HTTP status code for found
	 */
	Found = 302,

	/**
	 * @enum {number}
	 * @description HTTP status code for see other
	 */
	SeeOther = 303,

	/**
	 * @enum {number}
	 * @description HTTP status code for not modified
	 */
	NotModified = 304,

	/**
	 * @enum {number}
	 * @description HTTP status code for use proxy
	 */
	UseProxy = 305,

	/**
	 * @enum {number}
	 * @description HTTP status code for temporary redirect
	 */
	TemporaryRedirect = 307,

	/**
	 * @enum {number}
	 * @description HTTP status code for permanent redirect
	 */
	PermanentRedirect = 308,

	/** @description Client error: The server could not understand the request due to invalid syntax. */
	BadRequest = 400,

	/** @description Client error: The client must authenticate itself to get the requested response. */
	Unauthorized = 401,

	/** @description Client error: This response code is reserved for future use. */
	PaymentRequired = 402,

	/** @description Client error: The client does not have access rights to the content; that is, it is unauthorized, so the server is refusing to give the requested resource. */
	Forbidden = 403,

	/** @description Client error: The server cannot find requested resource. */
	NotFound = 404,

	/** @description Client error: The request method is not supported by the server and cannot be handled. */
	MethodNotAllowed = 405,

	/** @description Client error: This response is sent when the web server, after performing server-driven content negotiation, doesn't find any content following the criteria given by the user agent. */
	NotAcceptable = 406,

	/** @description Client error: This is similar to 401 (Unauthorised), but indicates that the client must authenticate itself to get the requested response. */
	ProxyAuthenticationRequired = 407,

	/** @description Client error: This response is sent on an idle connection by some servers, even without any previous request by the client. */
	RequestTimeout = 408,

	/** @description Client error: This response is sent when a request conflicts with the current state of the server. */
	Conflict = 409,

	/** @description Client error: This response is sent when the requested content has been permanently deleted from server, with no forwarding address. */
	Gone = 410,

	/** @description Client error: The server refuses to accept the request without a defined Content- Length. */
	LengthRequired = 411,

	/** @description Client error: The precondition given in the request evaluated to false by the server. */
	PreconditionFailed = 412,

	/** @description Client error: Request entity is larger than limits defined by server. */
	PayloadTooLarge = 413,

	/** @description Client error: The URI requested by the client is longer than the server is willing to interpret. */
	UriTooLong = 414,

	/** @description Client error: The media format of the requested data is not supported by the server, so the server is rejecting the request. */
	UnsupportedMediaType = 415,

	/** @description Client error: The range specified by the Range header field in the request can't be fulfilled. */
	RangeNotSatisfiable = 416,

	/** @description Client error: This response code means the expectation indicated by the Expect request header field can't be met by the server. */
	ExpectationFailed = 417,

	/** @description Client error: The server refuses to brew coffee because it is, permanently, a teapot. */
	ImATeapot = 418,

	/**
	 * @enum
	 * @name MisdirectedRequest
	 * @description Represents HTTP status code 421: Misdirected Request.
	 * The client should switch to a different protocol such as TLS/1.0.
	 */
	MisdirectedRequest = 421,

	/**
	 * @enum
	 * @name UnprocessableEntity
	 * @description Represents HTTP status code 422: Unprocessable Entity.
	 * The request was well-formed but was unable to be followed due to semantic errors.
	 */
	UnprocessableEntity = 422,

	/**
	 * @enum
	 * @name Locked
	 * @description Represents HTTP status code 423: Locked.
	 * The resource that is being accessed is locked.
	 */
	Locked = 423,

	/**
	 * @enum
	 * @name FailedDependency
	 * @description Represents HTTP status code 424: Failed Dependency.
	 * The request failed because it depended on another request and that request failed.
	 */
	FailedDependency = 424,

	/**
	 * @enum
	 * @name TooEarly
	 * @description Represents HTTP status code 425: Too Early.
	 * Indicates that the server is unwilling to risk processing a request that might be replayed.
	 */
	TooEarly = 425,

	/**
	 * @enum
	 * @name UpgradeRequired
	 * @description Represents HTTP status code 426: Upgrade Required.
	 * The client should switch to a different protocol.
	 */
	UpgradeRequired = 426,

	/**
	 * @enum
	 * @name PreconditionRequired
	 * @description Represents HTTP status code 428: Precondition Required.
	 * The client must first fulfill certain precondition.
	 */
	PreconditionRequired = 428,

	/**
	 * @enum
	 * @name TooManyRequests
	 * @description Represents HTTP status code 429: Too Many Requests.
	 * The user has sent too many requests in a certain amount of time.
	 */
	TooManyRequests = 429,

	/**
	 * @enum
	 * @name RequestHeaderFieldsTooLarge
	 * @description Represents HTTP status code 431: Request Header Fields Too Large.
	 * The server is unwilling to process the request because its header fields are too large.
	 */
	RequestHeaderFieldsTooLarge = 431,

	/**
	 * @enum
	 * @name UnavailableForLegalReasons
	 * @description Represents HTTP status code 451: Unavailable For Legal Reasons.
	 * The server is denying access for legal reasons.
	 */
	UnavailableForLegalReasons = 451,

	InternalServerError = 500,
	NotImplemented = 501,
	BadGateway = 502,
	ServiceUnavailable = 503,
	GatewayTimeout = 504,
	HttpVersionNotSupported = 505,
	VariantAlsoNegotiates = 506,
	InsufficientStorage = 507,
	LoopDetected = 508,
	NotExtended = 510,
	NetworkAuthenticationRequired = 511,
}
